
VERSION = (0, 1, 0)
"""Application version number tuple."""

VERSION_STR = '.'.join(map(str, VERSION))
"""Application version number string."""


default_app_config = 'sitetables.config.SitetablesConfig'
